@@ -5,7 +5,7 @@ using spdlog::memory_buf_t;
 
 // log to str and return it
 template<typename... Args>
-static std::string log_to_str(const std::string &msg, const Args &...args)
+static std::string log_to_str(const std::string &msg, const Args &... args)
 {
     std::ostringstream oss;
     auto oss_sink = std::make_shared<spdlog::sinks::ostream_sink_mt>(oss);
@@ -64,7 +64,7 @@ TEST_CASE("color range test1", "[pattern_formatter]")
     auto formatter = std::make_shared<spdlog::pattern_formatter>("%^%v%$", spdlog::pattern_time_type::local, "\n");
 
     memory_buf_t buf;
-    fmt::format_to(std::back_inserter(buf), "Hello");
+    spdlog::fmt_lib::format_to(std::back_inserter(buf), "Hello");
     memory_buf_t formatted;
     std::string logger_name = "test";
     spdlog::details::log_msg msg(logger_name, spdlog::level::info, spdlog::string_view_t(buf.data(), buf.size()));
@@ -273,7 +273,11 @@ TEST_CASE("clone-default-formatter", "[pattern_formatter]")
     formatter_1->format(msg, formatted_1);
     formatter_2->format(msg, formatted_2);
 
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted_1 == formatted_2);
+#else
     REQUIRE(fmt::to_string(formatted_1) == fmt::to_string(formatted_2));
+#endif
 }
 
 TEST_CASE("clone-default-formatter2", "[pattern_formatter]")
@@ -288,7 +292,11 @@ TEST_CASE("clone-default-formatter2", "[pattern_formatter]")
     formatter_1->format(msg, formatted_1);
     formatter_2->format(msg, formatted_2);
 
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted_1 == formatted_2);
+#else
     REQUIRE(fmt::to_string(formatted_1) == fmt::to_string(formatted_2));
+#endif
 }
 
 TEST_CASE("clone-formatter", "[pattern_formatter]")
@@ -302,7 +310,12 @@ TEST_CASE("clone-formatter", "[pattern_formatter]")
     memory_buf_t formatted_2;
     formatter_1->format(msg, formatted_1);
     formatter_2->format(msg, formatted_2);
+
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted_1 == formatted_2);
+#else
     REQUIRE(fmt::to_string(formatted_1) == fmt::to_string(formatted_2));
+#endif
 }
 
 TEST_CASE("clone-formatter-2", "[pattern_formatter]")
@@ -317,7 +330,12 @@ TEST_CASE("clone-formatter-2", "[pattern_formatter]")
     memory_buf_t formatted_2;
     formatter_1->format(msg, formatted_1);
     formatter_2->format(msg, formatted_2);
+
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted_1 == formatted_2);
+#else
     REQUIRE(fmt::to_string(formatted_1) == fmt::to_string(formatted_2));
+#endif
 }
 
 class custom_test_flag : public spdlog::custom_flag_formatter
@@ -362,9 +380,15 @@ TEST_CASE("clone-custom_formatter", "[pattern_formatter]")
     formatter_1->format(msg, formatted_1);
     formatter_2->format(msg, formatted_2);
 
-    auto expected = fmt::format("[logger-name] [custom_output] some message{}", spdlog::details::os::default_eol);
+    auto expected = spdlog::fmt_lib::format("[logger-name] [custom_output] some message{}", spdlog::details::os::default_eol);
+
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted_1 == expected);
+    REQUIRE(formatted_2 == expected);
+#else
     REQUIRE(fmt::to_string(formatted_1) == expected);
     REQUIRE(fmt::to_string(formatted_2) == expected);
+#endif
 }
 
 //
@@ -385,7 +409,12 @@ TEST_CASE("short filename formatter-1", "[pattern_formatter]")
     spdlog::source_loc source_loc{test_path, 123, "some_func()"};
     spdlog::details::log_msg msg(source_loc, "logger-name", spdlog::level::info, "Hello");
     formatter.format(msg, formatted);
+
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted == "myfile.cpp");
+#else
     REQUIRE(fmt::to_string(formatted) == "myfile.cpp");
+#endif
 }
 
 TEST_CASE("short filename formatter-2", "[pattern_formatter]")
@@ -396,7 +425,12 @@ TEST_CASE("short filename formatter-2", "[pattern_formatter]")
     spdlog::source_loc source_loc{"myfile.cpp", 123, "some_func()"};
     spdlog::details::log_msg msg(source_loc, "logger-name", spdlog::level::info, "Hello");
     formatter.format(msg, formatted);
+
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted == "myfile.cpp:123");
+#else
     REQUIRE(fmt::to_string(formatted) == "myfile.cpp:123");
+#endif
 }
 
 TEST_CASE("short filename formatter-3", "[pattern_formatter]")
@@ -407,7 +441,12 @@ TEST_CASE("short filename formatter-3", "[pattern_formatter]")
     spdlog::source_loc source_loc{"", 123, "some_func()"};
     spdlog::details::log_msg msg(source_loc, "logger-name", spdlog::level::info, "Hello");
     formatter.format(msg, formatted);
+
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted == " Hello");
+#else
     REQUIRE(fmt::to_string(formatted) == " Hello");
+#endif
 }
 
 TEST_CASE("full filename formatter", "[pattern_formatter]")
@@ -418,7 +457,12 @@ TEST_CASE("full filename formatter", "[pattern_formatter]")
     spdlog::source_loc source_loc{test_path, 123, "some_func()"};
     spdlog::details::log_msg msg(source_loc, "logger-name", spdlog::level::info, "Hello");
     formatter.format(msg, formatted);
+
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted == test_path);
+#else
     REQUIRE(fmt::to_string(formatted) == test_path);
+#endif
 }
 
 TEST_CASE("custom flags", "[pattern_formatter]")
@@ -430,8 +474,13 @@ TEST_CASE("custom flags", "[pattern_formatter]")
 
     spdlog::details::log_msg msg(spdlog::source_loc{}, "logger-name", spdlog::level::info, "some message");
     formatter->format(msg, formatted);
-    auto expected = fmt::format("[logger-name] [custom1] [custom2] some message{}", spdlog::details::os::default_eol);
+    auto expected = spdlog::fmt_lib::format("[logger-name] [custom1] [custom2] some message{}", spdlog::details::os::default_eol);
+
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted == expected);
+#else
     REQUIRE(fmt::to_string(formatted) == expected);
+#endif
 }
 
 TEST_CASE("custom flags-padding", "[pattern_formatter]")
@@ -443,8 +492,13 @@ TEST_CASE("custom flags-padding", "[pattern_formatter]")
 
     spdlog::details::log_msg msg(spdlog::source_loc{}, "logger-name", spdlog::level::info, "some message");
     formatter->format(msg, formatted);
-    auto expected = fmt::format("[logger-name] [custom1] [     custom2] some message{}", spdlog::details::os::default_eol);
+    auto expected = spdlog::fmt_lib::format("[logger-name] [custom1] [     custom2] some message{}", spdlog::details::os::default_eol);
+
+#ifdef SPDLOG_USE_STD_FORMAT
+    REQUIRE(formatted == expected);
+#else
     REQUIRE(fmt::to_string(formatted) == expected);
+#endif
 }
 
 TEST_CASE("custom flags-exception", "[pattern_formatter]")
